IPDB module — pyroute2 0.5.18 documentation

# IPDB module

Warning

The IPDB module is deprecated and obsoleted by NDB. Please consider using NDB instead.

- IPDB guide
  - Limitations
  - IPDB, NDB, IPRoute
  - IPDB and other software
  - Quickstart
  - Transaction modes
  - Context managers
  - Read-only interface views
  - Create interfaces
  - IP address management
  - Bridge interfaces
  - Bridge ports
  - Ports management
  - Routes management
  - Rules management
  - Performance issues
  - The class API